DisplayObserver

Struct DisplayObserver 

pub struct DisplayObserver { /* private fields */ }
A display observer that monitors changes to the display configuration.

Platform-specifics

  • Windows: Internally creates an invisible window to receive WM_DISPLAYCHANGE events.
  • macOS: Uses CGDisplayRegisterReconfigurationCallback to track display configuration changes.

Implementations

Source

impl DisplayObserver

pub fn new() -> Result<Self, Error>

Create the display observer instance.

Examples found in repository?
examples/observe_config.rs (line 8)
3fn main() {
4    #[cfg(target_os = "windows")]
5    display_config::windows::set_process_per_monitor_dpi_aware()
6        .expect("Failed to set process as DPI aware");
7
8    let monitor = DisplayObserver::new().expect("Failed to create the instance");
9    monitor.set_callback(|event| println!("{event:#?}"));
10    monitor.run().expect("Failed to run the application");
11}
pub fn set_callback<F>(&self, callback: F)
where F: FnMut(Event) + Send + 'static,

Sets the callback function to be invoked when a display event occurs.

Examples found in repository?
examples/observe_config.rs (line 9)
3fn main() {
4    #[cfg(target_os = "windows")]
5    display_config::windows::set_process_per_monitor_dpi_aware()
6        .expect("Failed to set process as DPI aware");
7
8    let monitor = DisplayObserver::new().expect("Failed to create the instance");
9    monitor.set_callback(|event| println!("{event:#?}"));
10    monitor.run().expect("Failed to run the application");
11}
pub fn remove_callback(&self)

Removes the currently set callback function. After calling this, no display events will be dispatched.

pub fn run(&self) -> Result<(), Error>

Run the event loop. Since macOS ui thread must be on main, this function must be called on main thread. If you call this on non-main thread, this will panic on macOS.

Examples found in repository?
examples/observe_config.rs (line 10)
3fn main() {
4    #[cfg(target_os = "windows")]
5    display_config::windows::set_process_per_monitor_dpi_aware()
6        .expect("Failed to set process as DPI aware");
7
8    let monitor = DisplayObserver::new().expect("Failed to create the instance");
9    monitor.set_callback(|event| println!("{event:#?}"));
10    monitor.run().expect("Failed to run the application");
11}